@@ -8,10 +8,16 @@
 
 package Gearman::XS::Task;
 
-our $VERSION= '0.4';
+use strict;
+use warnings;
+
+our $VERSION= '0.5';
 
 use Gearman::XS;
 
+1;
+__END__
+
 =head1 NAME
 
 Gearman::XS::Task - Perl task for gearman using libgearman
@@ -67,10 +73,13 @@ at your option, any later version of Perl 5 you may have available.
 
 This is free software. IT COMES WITHOUT WARRANTY OF ANY KIND.
 
-=head1 AUTHORS
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=head1 AUTHOR
 
 Dennis Schoen <dennis@blogma.de>
 
-=cut
-
-1;
\ No newline at end of file
+=cut
\ No newline at end of file
